@@ -94,6 +94,9 @@ pub struct Model {
     no_clear_if_empty: bool,
     theme: Arc<ColorTheme>,
 
+    // Minimum query length to show results
+    min_query_length: Option<usize>,
+
     // timer thread for scheduled events
     timer: Timer,
     hb_timer_guard: Option<TimerGuard>,
@@ -177,6 +180,7 @@ impl Model {
             info: InfoDisplay::Default,
             no_clear_if_empty: false,
             theme,
+            min_query_length: options.min_query_length,
             timer: Timer::new(),
             hb_timer_guard: None,
 
@@ -288,6 +292,20 @@ impl Model {
     }
 
     fn act_heart_beat(&mut self, env: &mut ModelEnv) {
+        // Check if query meets minimum length requirement
+        if let Some(min_length) = self.min_query_length {
+            // In normal mode, check query length
+            // In interactive mode, check cmd_query length
+            let query_to_check = if env.in_query_mode { &env.query } else { &env.cmd_query };
+
+            if query_to_check.chars().count() < min_length {
+                // Clear selection if query is too short
+                self.selection.clear();
+                // Exit early to prevent showing any results
+                return;
+            }
+        }
+
         // save the processed items
         let matcher_stopped = self
             .matcher_control
@@ -397,6 +415,18 @@ impl Model {
 
         // restart reader
         self.reader_control.replace(self.reader.run(&env.cmd));
+
+        // Check if query meets minimum length requirement before restarting matcher
+        // In interactive mode, the command query is used as the search query
+        if let Some(min_length) = self.min_query_length {
+            if env.cmd_query.chars().count() < min_length {
+                // Clear selection if query is too short
+                self.selection.clear();
+                // Don't restart matcher if query is too short
+                return;
+            }
+        }
+
         self.restart_matcher();
         self.reader_timer = Instant::now();
     }
@@ -406,9 +436,22 @@ impl Model {
         if let Some(ctrl) = self.matcher_control.take() {
             ctrl.kill();
         }
+
+        // Always clear selection when query changes
         env.clear_selection = ClearStrategy::Clear;
         self.item_pool.reset();
         self.num_options = 0;
+
+        // Check if query meets minimum length requirement
+        if let Some(min_length) = self.min_query_length {
+            if env.query.chars().count() < min_length {
+                // Clear selection if query is too short
+                self.selection.clear();
+                // Don't restart matcher if query is too short
+                return;
+            }
+        }
+
         self.restart_matcher();
     }
 
@@ -720,6 +763,23 @@ impl Model {
     fn restart_matcher(&mut self) {
         self.matcher_timer = Instant::now();
         let query = self.query.get_fz_query();
+        let cmd_query = self.query.get_cmd_query();
+        let in_query_mode = self.query.in_query_mode();
+
+        // Check if query meets minimum length requirement before doing anything
+        if let Some(min_length) = self.min_query_length {
+            // Check the appropriate query based on mode
+            let query_to_check = if in_query_mode { &query } else { &cmd_query };
+
+            if query_to_check.chars().count() < min_length {
+                // Don't run matcher if query is too short
+                // Also kill any existing matcher
+                if let Some(ctrl) = self.matcher_control.take() {
+                    ctrl.kill();
+                }
+                return;
+            }
+        }
 
         // kill existing matcher if exits
         if let Some(ctrl) = self.matcher_control.take() {
